@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -69,11 +41,13 @@ import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.AccountAware;
 import com.openexchange.file.storage.CompositeFileStorageAccountManagerProvider;
 import com.openexchange.file.storage.FileStorageAccount;
+import com.openexchange.file.storage.FileStorageAccountAccess;
 import com.openexchange.file.storage.FileStorageAccountDeleteListener;
 import com.openexchange.file.storage.FileStorageAccountManager;
 import com.openexchange.file.storage.FileStorageAccountManagerLookupService;
 import com.openexchange.file.storage.FileStorageAccountManagerProvider;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
+import com.openexchange.file.storage.LoginAwareFileStorageServiceExtension;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
@@ -93,7 +67,7 @@ import com.openexchange.session.Session;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public abstract class AbstractOAuthFileStorageService implements AccountAware, OAuthAccountDeleteListener, FileStorageAccountDeleteListener {
+public abstract class AbstractOAuthFileStorageService implements AccountAware, OAuthAccountDeleteListener, FileStorageAccountDeleteListener, LoginAwareFileStorageServiceExtension {
 
     private static final Logger LOG = LoggerFactory.getLogger(AbstractOAuthFileStorageService.class);
 
@@ -141,6 +115,15 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
         tmpDescription.add(oauthAccount);
         formDescription = new ReadOnlyDynamicFormDescription(tmpDescription);
     }
+    
+    @Override
+    public void testConnection(FileStorageAccount account, Session session) throws OXException {
+        FileStorageAccountAccess accountAccess = getAccountAccess(account.getId(), session);
+        if (false == accountAccess.isConnected()) {
+            accountAccess.connect();
+        }
+        accountAccess.ping();
+    }
 
     @Override
     public DynamicFormDescription getFormDescription() {
@@ -186,7 +169,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
         Integer iUserId = Integer.valueOf(user);
         Integer iContextId = Integer.valueOf(cid);
         try {
-            List<FileStorageAccount> toDelete = new LinkedList<FileStorageAccount>();
+            List<FileStorageAccount> toDelete = new LinkedList<>();
             FakeSession session = new FakeSession(null, user, cid);
             for (FileStorageAccount account : getAccounts0(session, false)) {
                 Object obj = account.getConfiguration().get("account");
@@ -203,7 +186,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
             // Pass the connection and the hint about the scopes to the FileStorageAccountManager
             // as a session parameter.
             session.setParameter(OAuthConstants.SESSION_PARAM_UPDATE_SCOPES, eventProps.get(OAuthConstants.SESSION_PARAM_UPDATE_SCOPES));
-            session.setParameter("__file.storage.delete.connection", con);
+            session.setParameter("__connection", con);
             try {
                 for (FileStorageAccount deleteMe : toDelete) {
                     accountManager.deleteAccount(deleteMe, session);
@@ -214,7 +197,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
                     }
                 }
             } finally {
-                session.setParameter("__file.storage.delete.connection", null);
+                session.setParameter("__connection", null);
                 session.setParameter(OAuthConstants.SESSION_PARAM_UPDATE_SCOPES, null);
             }
         } catch (Exception e) {
@@ -266,7 +249,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
             return;
         }
 
-        session.setParameter("__file.storage.delete.connection", con);
+        session.setParameter("__connection", con);
         try {
             OAuthService storage = services.getService(OAuthService.class);
             if (storage == null) {
@@ -302,7 +285,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
             // Update the account
             storage.updateAccount(session, accountId, eventProps);
         } finally {
-            session.setParameter("__file.storage.delete.connection", null);
+            session.setParameter("__connection", null);
         }
     }
 
@@ -374,7 +357,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
             return getAccountManager0(secretAware).getAccounts(session);
         }
 
-        Map<String, FileStorageAccountInfo> accountsMap = new LinkedHashMap<String, FileStorageAccountInfo>(8);
+        Map<String, FileStorageAccountInfo> accountsMap = new LinkedHashMap<>(8);
         for (FileStorageAccountManagerProvider provider : compositeAccountManager.providers()) {
             for (FileStorageAccount account : newInstanceFor(provider.getAccountManagerFor(getId())).getAccounts(session)) {
                 FileStorageAccountInfo info = new FileStorageAccountInfo(account, provider.getRanking());
@@ -386,7 +369,7 @@ public abstract class AbstractOAuthFileStorageService implements AccountAware, O
             }
         }
 
-        List<FileStorageAccount> ret = new ArrayList<FileStorageAccount>(accountsMap.size());
+        List<FileStorageAccount> ret = new ArrayList<>(accountsMap.size());
         for (FileStorageAccountInfo info : accountsMap.values()) {
             ret.add(info.getAccount());
         }
