@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2018-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -92,7 +64,7 @@ abstract class AbstractMicrosoftGraphAPI {
 
     /**
      * Gets the REST resource from the specified path
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The resource's path
      * @return A {@link JSONObject} with the resource
@@ -105,7 +77,7 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Gets the REST resource from the specified path and the specified query
      * parameters
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The resource's path
      * @param queryParams the request's query parameters
@@ -119,20 +91,20 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Gets the stream from the specified path. Use to stream data from the
      * remote end-point to the client, i.e. download.
-     * 
+     *
      * @param path The path
      * @return The {@link InputStream}
      * @throws OXException if an error is occurred
      */
     InputStream getStream(String path) throws OXException {
-        return client.download(new HttpGet(path));
+        return client.download(() -> new HttpGet(path));
     }
 
     //////////////////////////////// POST ///////////////////////////////////////
 
     /**
      * Posts the specified {@link JSONObject} body to the specified path
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The path
      * @param body The body to post
@@ -141,7 +113,7 @@ abstract class AbstractMicrosoftGraphAPI {
      */
     JSONObject postResource(String accessToken, String path, JSONObject body) throws OXException {
         MicrosoftGraphRequest request = createRequest(RESTMethod.POST, accessToken, path);
-        request.sethBodyEntity(new JSONObjectEntity(body));
+        request.setBodyEntity(new JSONObjectEntity(body));
         return executeRequest(request);
     }
 
@@ -149,7 +121,7 @@ abstract class AbstractMicrosoftGraphAPI {
 
     /**
      * Puts the specified {@link JSONObject} body to the specified path
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The path
      * @param body The body to post
@@ -158,7 +130,7 @@ abstract class AbstractMicrosoftGraphAPI {
      */
     JSONObject putResource(String accessToken, String path, String contentType, InputStream body) throws OXException {
         MicrosoftGraphRequest request = createRequest(RESTMethod.PUT, accessToken, path, contentType);
-        request.sethBodyEntity(new InputStreamEntity(body, contentType));
+        request.setBodyEntity(new InputStreamEntity(body, contentType));
         return executeRequest(request);
     }
 
@@ -166,7 +138,7 @@ abstract class AbstractMicrosoftGraphAPI {
 
     /**
      * Deletes a resource
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The path
      * @throws OXException if an error is occurred
@@ -179,7 +151,7 @@ abstract class AbstractMicrosoftGraphAPI {
 
     /**
      * Patches the specified {@link JSONObject} body to the specified path
-     * 
+     *
      * @param accessToken The oauth access token
      * @param path The path
      * @param body The body to post
@@ -188,7 +160,7 @@ abstract class AbstractMicrosoftGraphAPI {
      */
     JSONObject patchResource(String accessToken, String path, JSONObject body) throws OXException {
         MicrosoftGraphRequest request = createRequest(RESTMethod.PATCH, accessToken, path);
-        request.sethBodyEntity(new JSONObjectEntity(body));
+        request.setBodyEntity(new JSONObjectEntity(body));
         return executeRequest(request);
     }
 
@@ -197,7 +169,7 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Creates a {@link MicrosoftGraphRequest} with the specified {@link RESTMethod} and access token
      * for the specified end-point
-     * 
+     *
      * @param method the {@link RESTMethod}
      * @param accessToken The oauth access token
      * @param path The path
@@ -210,7 +182,7 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Creates a {@link MicrosoftGraphRequest} with the specified {@link RESTMethod}, access token
      * and content type for the specified end-point
-     * 
+     *
      * @param method the {@link RESTMethod}
      * @param accessToken The oauth access token
      * @param path The path
@@ -224,7 +196,7 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Creates a {@link MicrosoftGraphRequest} with the specified {@link RESTMethod}, access token
      * and query parameters for the specified end-point
-     * 
+     *
      * @param method the {@link RESTMethod}
      * @param accessToken The oauth access token
      * @param path The path
@@ -238,7 +210,7 @@ abstract class AbstractMicrosoftGraphAPI {
     /**
      * Creates a {@link MicrosoftGraphRequest} with the specified {@link RESTMethod}, access token, content type
      * and query parameters for the specified end-point
-     * 
+     *
      * @param method the {@link RESTMethod}
      * @param accessToken The oauth access token
      * @param path The path
@@ -258,7 +230,7 @@ abstract class AbstractMicrosoftGraphAPI {
 
     /**
      * Executes the specified {@link MicrosoftGraphRequest}
-     * 
+     *
      * @param request the request to execute
      * @return The response body as a {@link JSONObject}
      * @throws OXException if an error is occurred
