@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2018-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -287,7 +259,7 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
         MicrosoftGraphRequest request = new MicrosoftGraphRequest(RESTMethod.POST, BASE_URL + "/items/" + itemId + "/copy");
         request.setAccessToken(accessToken);
         request.setHeader(HttpHeaders.CONTENT_TYPE, "application/json");
-        request.sethBodyEntity(new JSONObjectEntity(body));
+        request.setBodyEntity(new JSONObjectEntity(body));
         RESTResponse restResponse = client.execute(request);
         if (restResponse.getStatusCode() == 202) {
             return restResponse.getHeader(HttpHeaders.LOCATION);
@@ -309,7 +281,7 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
         MicrosoftGraphRequest request = new MicrosoftGraphRequest(RESTMethod.POST, BASE_URL + "/items/" + itemId + "/copy");
         request.setAccessToken(accessToken);
         request.setHeader(HttpHeaders.CONTENT_TYPE, "application/json");
-        request.sethBodyEntity(new JSONObjectEntity(body));
+        request.setBodyEntity(new JSONObjectEntity(body));
         RESTResponse restResponse = client.execute(request);
         String location = restResponse.getHeader(HttpHeaders.LOCATION);
         if (Strings.isEmpty(location)) {
@@ -467,7 +439,8 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
      * 
      * @param accessToken The oauth access token
      * @param folderId The folder identifier of the parent folder (if empty or <code>null</code> the root folder will be used)
-     * @param filename The file's name
+     * @param fileId The optional file identifier (For existing files)
+     * @param filename The optional file name (For new files)
      * @param contentType The content type of the file
      * @param inputStream A stream with the actual data
      * @return A {@link JSONObject} with the metadata of the newly uploaded file.
@@ -475,8 +448,8 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
      * @see <a href="https://docs.microsoft.com/en-us/graph/api/driveitem-put-content?view=graph-rest-1.0">Upload small files</a>
      * 
      */
-    public JSONObject oneshotUpload(String accessToken, String folderId, String filename, String contentType, InputStream inputStream) throws OXException {
-        String path = BASE_URL + (Strings.isEmpty(folderId) ? "/root" : "/items/" + folderId) + ":/" + filename + ":/content";
+    public JSONObject oneshotUpload(String accessToken, String folderId, String fileId, String filename, String contentType, InputStream inputStream) throws OXException {
+        String path = compileUploadURL(folderId, fileId, filename, true);
         return putResource(accessToken, path, contentType, inputStream);
     }
 
@@ -487,7 +460,8 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
      *
      * @param accessToken The oauth access token
      * @param folderId The folder identifier of the parent folder (if empty or <code>null</code> the root folder will be used)
-     * @param filename The file's name
+     * @param fileId The optional file identifier (For existing files)
+     * @param filename The optional file name (For new files)
      * @param contentLength The file's size
      * @param inputStream A stream with the actual data
      * @return A {@link JSONObject} with the metadata of the newly uploaded file.
@@ -495,11 +469,11 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
      * @throws IllegalArgumentException if the content length of the file is less than or equal to zero.
      * @see <a href="https://developer.microsoft.com/en-us/graph/docs/api-reference/v1.0/api/driveitem_createuploadsession">Resumable Upload</a>
      */
-    public JSONObject streamingUpload(String accessToken, String folderId, String filename, long contentLength, InputStream inputStream) throws OXException {
+    public JSONObject streamingUpload(String accessToken, String folderId, String fileId, String filename, long contentLength, InputStream inputStream) throws OXException {
         if (contentLength <= 0) {
             throw new IllegalArgumentException("The content length of the file must be greater than zero!");
         }
-        String path = BASE_URL + (Strings.isEmpty(folderId) ? "/root" : "/items/" + folderId) + ":/" + filename + ":/createUploadSession";
+        String path = compileUploadURL(folderId, fileId, filename, false);
         try (BufferedInputStream bis = new BufferedInputStream(inputStream)) {
             JSONObject body = new JSONObject();
             body.put("name", filename);
@@ -553,4 +527,25 @@ public class MicrosoftGraphOneDriveAPI extends AbstractMicrosoftGraphAPI {
             throw RESTExceptionCodes.IO_ERROR.create(e);
         }
     }
+
+    /**
+     * Compiles the upload URL. Either one of fileId or filename MUST be present. The oneShot indicates
+     * whether a stream upload URL will be compiled, or the one-shot
+     *
+     * @param folderId The folder identifier
+     * @param fileId The optional file identifier (For existing files)
+     * @param filename The optional file name (For new files)
+     * @param oneShot Whether an oneShot URL or a streaming URL shall be compiled
+     * @return The URL
+     * @throws OXException if both fileId and filename are missing
+     */
+    private String compileUploadURL(String folderId, String fileId, String filename, boolean oneShot) throws OXException {
+        if (Strings.isEmpty(fileId) && Strings.isEmpty(filename)) {
+            throw MicrosoftGraphAPIExceptionCodes.INVALID_REQUEST.create("Either filename or fileId must be present");
+        }
+        if (Strings.isEmpty(filename)) {
+            return BASE_URL + "/items/" + fileId + "/" + (oneShot ? "content" : "createUploadSession"); // Update path
+        }
+        return BASE_URL + (Strings.isEmpty(folderId) ? "/root" : "/items/" + folderId) + ":/" + filename + ":/" + (oneShot ? "content" : "createUploadSession"); // New path
+    }
 }
