@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -87,25 +59,25 @@ public abstract class AbstractExtendedScribeAwareOAuthServiceMetaData extends Ab
     private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(AbstractExtendedScribeAwareOAuthServiceMetaData.class);
 
     /**
-     * Initialises a new {@link AbstractExtendedScribeAwareOAuthServiceMetaData}.
+     * Initializes a new {@link AbstractExtendedScribeAwareOAuthServiceMetaData}.
      *
      * @param services The {@link ServiceLookup}
      * @param api The {@link DefaultAPI}
      * @param scopes The {@link OAuthScope}s
      */
-    public AbstractExtendedScribeAwareOAuthServiceMetaData(ServiceLookup services, API api, OAuthScope... scopes) {
+    protected AbstractExtendedScribeAwareOAuthServiceMetaData(ServiceLookup services, API api, OAuthScope... scopes) {
         this(services, api, false, true, scopes);
     }
 
     /**
-     * Initialises a new {@link AbstractExtendedScribeAwareOAuthServiceMetaData}.
+     * Initializes a new {@link AbstractExtendedScribeAwareOAuthServiceMetaData}.
      *
      * @param services The {@link ServiceLookup} instance
      * @param api The {@link DefaultAPI}
      * @param needsRequestToken Whether it needs a request token
      * @param registerTokenBasedDeferrer Whether to register the token based deferrer
      */
-    public AbstractExtendedScribeAwareOAuthServiceMetaData(ServiceLookup services, API api, boolean needsRequestToken, boolean registerTokenBasedDeferrer, OAuthScope... scopes) {
+    protected AbstractExtendedScribeAwareOAuthServiceMetaData(ServiceLookup services, API api, boolean needsRequestToken, boolean registerTokenBasedDeferrer, OAuthScope... scopes) {
         super(services, api, scopes);
         this.needsRequestToken = needsRequestToken;
         this.registerTokenBasedDeferrer = registerTokenBasedDeferrer;
@@ -199,7 +171,7 @@ public abstract class AbstractExtendedScribeAwareOAuthServiceMetaData extends Ab
         Verifier verifier = new Verifier((String) arguments.get(org.scribe.model.OAuthConstants.CODE));
         Token accessToken = scribeOAuthService.getAccessToken(null, verifier);
 
-        return new DefaultOAuthToken(accessToken.getToken(), accessToken.getSecret());
+        return new DefaultOAuthToken(accessToken.getToken(), accessToken.getSecret(), accessToken.getExpiry() == null ? 0L : accessToken.getExpiry().getTime());
     }
 
     @Override
@@ -256,7 +228,7 @@ public abstract class AbstractExtendedScribeAwareOAuthServiceMetaData extends Ab
      * Extracts the protocol from the specified URL
      *
      * @param url The URL
-     * @return The extracted protocol (either http or https)
+     * @return The extracted protocol (either <code>"http"</code> or <code>"https"</code>)
      */
     private String extractProtocol(final String url) {
         return Strings.toLowerCase(url).startsWith("https") ? "https" : "http";
