@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -60,6 +32,8 @@ import org.scribe.model.OAuthRequest;
 import org.scribe.model.Token;
 import org.scribe.model.Verb;
 import org.scribe.oauth.OAuthService;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.http.client.builder.HTTPGenericRequestBuilder;
 import com.openexchange.http.client.builder.HTTPRequest;
@@ -72,6 +46,8 @@ import com.openexchange.oauth.impl.httpclient.OAuthHTTPRequestBuilder;
 
 public abstract class ScribeGenericHTTPRequestBuilder<T extends HTTPGenericRequestBuilder<T>> {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(ScribeGenericHTTPRequestBuilder.class);
+
     protected final Map<String, String> parameters;
     protected final Map<String, String> headers;
     protected final OAuthHTTPRequestBuilder coreBuilder;
@@ -81,6 +57,7 @@ public abstract class ScribeGenericHTTPRequestBuilder<T extends HTTPGenericReque
     protected final OAuthService scribeOAuthService;
     protected final Class<? extends org.scribe.builder.api.Api> provider;
 
+
     /**
      * Initializes a new {@link ScribeGenericHTTPRequestBuilder}.
      *
@@ -89,8 +66,8 @@ public abstract class ScribeGenericHTTPRequestBuilder<T extends HTTPGenericReque
      */
     protected ScribeGenericHTTPRequestBuilder(final OAuthHTTPRequestBuilder coreBuilder) {
         super();
-        parameters = new TreeMap<String, String>();
-        headers = new TreeMap<String, String>();
+        parameters = new TreeMap<>();
+        headers = new TreeMap<>();
         this.coreBuilder = coreBuilder;
         provider = getProvider(coreBuilder.getApi());
         scribeOAuthService = new ServiceBuilder().provider(getProvider(coreBuilder.getApi())).apiKey(coreBuilder.getApiKey()).apiSecret(coreBuilder.getSecret()).build();
@@ -169,6 +146,7 @@ public abstract class ScribeGenericHTTPRequestBuilder<T extends HTTPGenericReque
             try {
                 finalUrl = isVerbatimUrl ? verbatimUrl : new URIBuilder(baseUrl).build().toString();
             } catch (URISyntaxException e) {
+                LOGGER.debug("Unable to build URL.", e);
                 finalUrl = baseUrl;
             }
             request = new OAuthRequest(getVerb(), finalUrl);
