@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -136,12 +108,12 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         int user = session.getUserId();
 
         // Crypt tokens
-        ((DefaultOAuthToken) account).setToken(encrypt(account.getToken(), session));
-        ((DefaultOAuthToken) account).setSecret(encrypt(account.getSecret(), session));
-        ((DefaultOAuthAccount) account).setId(idGenerator.getId(OAuthConstants.TYPE_ACCOUNT, contextId));
+        DefaultOAuthToken.class.cast(account).setToken(encrypt(account.getToken(), session));
+        DefaultOAuthToken.class.cast(account).setSecret(encrypt(account.getSecret(), session));
+        DefaultOAuthAccount.class.cast(account).setId(idGenerator.getId(OAuthConstants.TYPE_ACCOUNT, contextId));
 
         // Create INSERT command
-        ArrayList<Object> values = new ArrayList<Object>(SQLStructure.OAUTH_COLUMN.values().length);
+        ArrayList<Object> values = new ArrayList<>(SQLStructure.OAUTH_COLUMN.values().length);
         INSERT insert = SQLStructure.insertAccount(account, contextId, user, values);
         // Execute INSERT command
         executeUpdate(contextId, insert, values);
@@ -151,7 +123,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
 
     @Override
     public OAuthAccount getAccount(Session session, int accountId, boolean loadSecrets) throws OXException {
-        Connection connection = (Connection) session.getParameter("__file.storage.delete.connection");
+        Connection connection = Connection.class.cast(session.getParameter("__connection"));
         try {
             if (connection != null && Databases.isInTransaction(connection)) {
                 // Given connection is already in transaction. Invoke & return immediately.
@@ -190,7 +162,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         int userId = session.getUserId();
         int contextId = session.getContextId();
 
-        Connection connection = (Connection) session.getParameter("__file.storage.delete.connection");
+        Connection connection = Connection.class.cast(session.getParameter("__connection"));
         if (connection != null) {
             try {
                 if (Databases.isInTransaction(connection)) {
@@ -243,8 +215,8 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
     @Override
     public void updateAccount(Session session, OAuthAccount account) throws OXException {
         // Crypt tokens
-        ((DefaultOAuthToken) account).setToken(encrypt(account.getToken(), session));
-        ((DefaultOAuthToken) account).setSecret(encrypt(account.getSecret(), session));
+        DefaultOAuthToken.class.cast(account).setToken(encrypt(account.getToken(), session));
+        DefaultOAuthToken.class.cast(account).setSecret(encrypt(account.getSecret(), session));
         /*
          * Get connection
          */
@@ -257,7 +229,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             /*
              * Create UPDATE command
              */
-            final ArrayList<Object> values = new ArrayList<Object>(SQLStructure.OAUTH_COLUMN.values().length);
+            final ArrayList<Object> values = new ArrayList<>(SQLStructure.OAUTH_COLUMN.values().length);
             final UPDATE update = SQLStructure.updateAccount(account, contextId, userId, values);
             Databases.startTransaction(writeCon);
             rollback = 1;
@@ -313,7 +285,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         if (list.isEmpty()) {
             return;
         }
-        Connection connection = (Connection) session.getParameter("__file.storage.delete.connection");
+        Connection connection = Connection.class.cast(session.getParameter("__connection"));
         try {
             if (connection != null && Databases.isInTransaction(connection)) {
                 // Given connection is already in transaction. Invoke & return immediately.
@@ -346,7 +318,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         ResultSet rs = null;
         Connection connection = getConnection(true, context);
         try {
-            stmt = connection.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ? AND identity = ?");
+            stmt = connection.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity, expiryDate FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ? AND identity = ?");
             stmt.setInt(1, contextId);
             stmt.setInt(2, userId);
             stmt.setString(3, serviceId);
@@ -379,6 +351,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             Set<OAuthScope> enabledScopes = scopeRegistry.getAvailableScopes(account.getMetaData().getAPI(), OXScope.valuesOf(scopes));
             account.setEnabledScopes(enabledScopes);
             account.setUserIdentity(rs.getString(7));
+            account.setExpiration(rs.getLong(8));
             return account;
         } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
@@ -405,14 +378,14 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         ResultSet rs = null;
         final Connection con = getConnection(true, context);
         try {
-            stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ?");
+            stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity, expiryDate FROM oauthAccounts WHERE cid = ? AND user = ?");
             stmt.setInt(1, contextId);
             stmt.setInt(2, userId);
             rs = stmt.executeQuery();
             if (!rs.next()) {
                 return Collections.emptyList();
             }
-            final List<OAuthAccount> accounts = new ArrayList<OAuthAccount>(8);
+            final List<OAuthAccount> accounts = new ArrayList<>(8);
             do {
                 try {
                     final DefaultOAuthAccount account = new DefaultOAuthAccount();
@@ -432,6 +405,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                         account.setEnabledScopes(enabledScopes);
                     }
                     account.setUserIdentity(rs.getString(7));
+                    account.setExpiration(rs.getLong(8));
                     accounts.add(account);
                 } catch (OXException e) {
                     if (!OAuthExceptionCodes.UNKNOWN_OAUTH_SERVICE_META_DATA.equals(e)) {
@@ -462,7 +436,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         ResultSet rs = null;
         final Connection con = getConnection(true, context);
         try {
-            stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ?");
+            stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, scope, identity, expiryDate FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ?");
             stmt.setInt(1, contextId);
             stmt.setInt(2, userId);
             stmt.setString(3, serviceMetaData);
@@ -470,7 +444,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             if (!rs.next()) {
                 return Collections.emptyList();
             }
-            final List<OAuthAccount> accounts = new ArrayList<OAuthAccount>(8);
+            final List<OAuthAccount> accounts = new ArrayList<>(8);
             do {
 
                 try {
@@ -489,6 +463,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     Set<OAuthScope> enabledScopes = scopeRegistry.getAvailableScopes(account.getMetaData().getAPI(), OXScope.valuesOf(scopes));
                     account.setEnabledScopes(enabledScopes);
                     account.setUserIdentity(rs.getString(6));
+                    account.setExpiration(rs.getLong(7));
                     accounts.add(account);
                 } catch (OXException e) {
                     if (!OAuthExceptionCodes.UNKNOWN_OAUTH_SERVICE_META_DATA.equals(e)) {
@@ -565,7 +540,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             if (!rs.next()) {
                 return;
             }
-            final List<OAuthAccount> accounts = new ArrayList<OAuthAccount>(8);
+            final List<OAuthAccount> accounts = new ArrayList<>(8);
             do {
                 try {
                     // Try using the new secret. Maybe this account doesn't need the migration
@@ -578,9 +553,11 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                         cryptoService.decrypt(accessSecret, newSecret);
                     }
                 } catch (OXException e) {
+                    int accountId = rs.getInt(1);
+                    LOG.debug("Cannot decrypt access token and/or secret tokens with old password. The account with id {} of user {} in context {} needs migration.", I(accountId), I(session.getUserId()), I(contextId), e);
                     // Needs migration
                     final DefaultOAuthAccount account = new DefaultOAuthAccount();
-                    account.setId(rs.getInt(1));
+                    account.setId(accountId);
                     account.setToken(cryptoService.decrypt(rs.getString(2), oldSecret));
                     account.setSecret(cryptoService.decrypt(rs.getString(3), oldSecret));
                     accounts.add(account);
@@ -629,7 +606,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             if (!rs.next()) {
                 return;
             }
-            final List<Integer> accounts = new ArrayList<Integer>(8);
+            final List<Integer> accounts = new ArrayList<>(8);
             do {
                 try {
                     // Try using the secret.
@@ -643,7 +620,9 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     }
                 } catch (OXException e) {
                     // Clean-up
-                    accounts.add(Integer.valueOf(rs.getInt(1)));
+                    int accountId = rs.getInt(1);
+                    LOG.debug("Cannot encrypt access and/or secret tokens of account {} for user {} in context {}. Performing clean-up", I(accountId), I(session.getUserId()), I(contextId), e);
+                    accounts.add(I(accountId));
                 }
             } while (rs.next());
             closeSQLStuff(rs, stmt);
@@ -701,7 +680,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             if (!rs.next()) {
                 return;
             }
-            final List<Integer> accounts = new ArrayList<Integer>(8);
+            final List<Integer> accounts = new ArrayList<>(8);
             do {
                 try {
                     // Try using the secret.
@@ -715,6 +694,8 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     }
                 } catch (OXException e) {
                     // Clean-up
+                    int accountId = rs.getInt(1);
+                    LOG.debug("Cannot decrypt access and/or secret tokens of account {} for user {} in context {}. Removing unrecoverable item.", I(accountId), I(session.getUserId()), I(contextId), e);
                     accounts.add(Integer.valueOf(rs.getInt(1)));
                 }
             } while (rs.next());
@@ -840,7 +821,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            stmt = connection.prepareStatement("SELECT displayName, accessToken, accessSecret, serviceId, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ? and id = ?");
+            stmt = connection.prepareStatement("SELECT displayName, accessToken, accessSecret, serviceId, scope, identity, expiryDate FROM oauthAccounts WHERE cid = ? AND user = ? and id = ?");
             int contextId = session.getContextId();
             int userId = session.getUserId();
             stmt.setInt(1, contextId);
@@ -879,6 +860,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             Set<OAuthScope> enabledScopes = scopeRegistry.getAvailableScopes(account.getMetaData().getAPI(), OXScope.valuesOf(scopes));
             account.setEnabledScopes(enabledScopes);
             account.setUserIdentity(rs.getString(6));
+            account.setExpiration(rs.getLong(7));
             return account;
         } finally {
             closeSQLStuff(rs, stmt);
@@ -1088,7 +1070,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      */
     @SuppressWarnings("unchecked")
     private List<Setter> setterFrom(final Map<String, Object> arguments, int accountId) throws OXException {
-        final List<Setter> ret = new ArrayList<Setter>(4);
+        final List<Setter> ret = new ArrayList<>(4);
         /*
          * Check for display name
          */
@@ -1122,21 +1104,23 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             }
             final String sToken = encrypt(token.getToken(), session);
             final String secret = encrypt(token.getSecret(), session);
+            final long expiry = token.getExpiration();
             ret.add(new Setter() {
 
                 @Override
                 public int set(final int pos, final PreparedStatement stmt) throws SQLException {
                     stmt.setString(pos, sToken);
                     stmt.setString(pos + 1, secret);
+                    stmt.setLong(pos + 2, expiry);
                     if (Strings.isEmpty(secret)) {
                         LOG.debug("Setting empty OAuth secret for account '{}' of user '{}' in context '{}'", I(accountId), I(session.getUserId()), I(session.getContextId()));
                     }
-                    return pos + 2;
+                    return pos + 3;
                 }
 
                 @Override
                 public void appendTo(final StringBuilder stmtBuilder) {
-                    stmtBuilder.append("accessToken = ?, accessSecret = ?");
+                    stmtBuilder.append("accessToken = ?, accessSecret = ?, expiryDate = ?");
                 }
             });
         }
