@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -65,6 +37,7 @@ import org.scribe.builder.api.Api;
 import org.scribe.exceptions.OAuthException;
 import org.scribe.model.Token;
 import org.scribe.model.Verifier;
+import org.scribe.oauth.OAuth20ServiceImpl;
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.html.HtmlService;
@@ -130,7 +103,7 @@ public class OAuthServiceImpl implements OAuthService {
     }
 
     @Override
-    public List<OAuthAccount> getAccounts(final Session session) throws OXException {
+    public List<OAuthAccount> getAccounts(Session session) throws OXException {
         return oauthAccountStorage.getAccounts(session);
     }
 
@@ -140,14 +113,14 @@ public class OAuthServiceImpl implements OAuthService {
     }
 
     @Override
-    public OAuthInteraction initOAuth(final Session session, final String serviceMetaData, final String callbackUrl, final HostInfo currentHost, Set<OAuthScope> scopes) throws OXException {
+    public OAuthInteraction initOAuth(Session session, String serviceMetaData, String callbackUrl, HostInfo currentHost, Set<OAuthScope> scopes) throws OXException {
         try {
-            final int contextId = session.getContextId();
-            final int userId = session.getUserId();
-            final OAuthServiceMetaData metaData = registry.getService(serviceMetaData, userId, contextId);
+            int contextId = session.getContextId();
+            int userId = session.getUserId();
+            OAuthServiceMetaData metaData = registry.getService(serviceMetaData, userId, contextId);
 
             // Check for individual OAuthInteraction
-            final OAuthInteraction interaction = metaData.initOAuth(callbackUrl, session);
+            OAuthInteraction interaction = metaData.initOAuth(callbackUrl, session);
             if (interaction != null) {
                 return interaction;
             }
@@ -155,7 +128,7 @@ public class OAuthServiceImpl implements OAuthService {
 
             // Apply possible modifications to call-back URL
             {
-                final String modifiedUrl = metaData.modifyCallbackURL(cbUrl, currentHost, session);
+                String modifiedUrl = metaData.modifyCallbackURL(cbUrl, currentHost, session);
                 if (modifiedUrl != null) {
                     cbUrl = modifiedUrl;
                 }
@@ -186,7 +159,7 @@ public class OAuthServiceImpl implements OAuthService {
             }
 
             // Process authorization URL
-            final String authURL = metaData.processAuthorizationURLCallbackAware(metaData.processAuthorizationURL(authorizationURL.toString(), session), cbUrl);
+            String authURL = metaData.processAuthorizationURLCallbackAware(metaData.processAuthorizationURL(authorizationURL.toString(), session), cbUrl);
             // Register deferrer
             if (metaData.registerTokenBasedDeferrer()) {
                 // Register by token
@@ -216,7 +189,7 @@ public class OAuthServiceImpl implements OAuthService {
     }
 
     @Override
-    public OAuthAccount createAccount(Session session, final String serviceMetaData, Set<OAuthScope> scopes, final Map<String, Object> arguments) throws OXException {
+    public OAuthAccount createAccount(Session session, String serviceMetaData, Set<OAuthScope> scopes, Map<String, Object> arguments) throws OXException {
         isNull(arguments, OAuthConstants.ARGUMENT_DISPLAY_NAME, OAuthConstants.ARGUMENT_SESSION, OAuthConstants.ARGUMENT_TOKEN, OAuthConstants.ARGUMENT_SECRET);
         // Create appropriate OAuth account instance
         DefaultOAuthAccount account = new DefaultOAuthAccount();
@@ -224,14 +197,13 @@ public class OAuthServiceImpl implements OAuthService {
         OAuthServiceMetaData service = registry.getService(serviceMetaData, session.getUserId(), session.getContextId());
         account.setMetaData(service);
         // Set display name & identifier
-        String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
+        String displayName = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME));
         account.setDisplayName(displayName);
         // Token & secret
-        account.setToken((String) arguments.get(OAuthConstants.ARGUMENT_TOKEN));
-        account.setSecret((String) arguments.get(OAuthConstants.ARGUMENT_SECRET));
+        account.setToken(String.class.cast(arguments.get(OAuthConstants.ARGUMENT_TOKEN)));
+        account.setSecret(String.class.cast(arguments.get(OAuthConstants.ARGUMENT_SECRET)));
         account.setEnabledScopes(scopes);
         // Store the account
-        //Session session = (Session) arguments.get(OAuthConstants.ARGUMENT_SESSION);
         oauthAccountStorage.storeAccount(session, account);
         return account;
     }
@@ -246,15 +218,14 @@ public class OAuthServiceImpl implements OAuthService {
 
         isNull(arguments, OAuthConstants.ARGUMENT_SESSION);
 
-        String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
+        String displayName = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME));
         account.setDisplayName(displayName);
         account.setEnabledScopes(scopes);
 
-        //Session session = (Session) arguments.get(OAuthConstants.ARGUMENT_SESSION);
         String userIdentity = service.getUserIdentity(session, accountId, account.getToken(), account.getSecret());
         account.setUserIdentity(userIdentity);
 
-        String actionHint = (String) arguments.get(OAuthConstants.ARGUMENT_ACTION_HINT);
+        String actionHint = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_ACTION_HINT));
         DefaultOAuthAccount existingAccount = getExistingAccount(session, userIdentity, serviceMetaData, accountId);
 
         if (existingAccount == null) {
@@ -285,12 +256,13 @@ public class OAuthServiceImpl implements OAuthService {
             existingAccount.addEnabledScope(scope);
         }
         existingAccount.setUserIdentity(userIdentity);
+        existingAccount.setExpiration(account.getExpiration());
         oauthAccountStorage.updateAccount(session, existingAccount);
         return existingAccount;
     }
 
     @Override
-    public OAuthAccount createAccount(Session session, final String serviceMetaData, Set<OAuthScope> scopes, final OAuthInteractionType type, final Map<String, Object> arguments) throws OXException {
+    public OAuthAccount createAccount(Session session, String serviceMetaData, Set<OAuthScope> scopes, OAuthInteractionType type, Map<String, Object> arguments) throws OXException {
         isNull(arguments, OAuthConstants.ARGUMENT_DISPLAY_NAME, OAuthConstants.ARGUMENT_SESSION);
         try {
             DefaultOAuthAccount account = new DefaultOAuthAccount();
@@ -298,7 +270,7 @@ public class OAuthServiceImpl implements OAuthService {
             OAuthServiceMetaData service = registry.getService(serviceMetaData, session.getUserId(), session.getContextId());
             account.setMetaData(service);
 
-            String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
+            String displayName = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME));
             account.setDisplayName(displayName);
 
             obtainToken(type, arguments, account, scopes);
@@ -320,7 +292,7 @@ public class OAuthServiceImpl implements OAuthService {
             return account;
         } catch (OXException x) {
             if (ExceptionUtils.isEitherOf(x, SSLHandshakeException.class)) {
-                String url = (String) arguments.get(OAuthConstants.ARGUMENT_AUTH_URL);
+                String url = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_AUTH_URL));
                 if (Strings.isNotEmpty(url)) {
                     try {
                         url = new URI(url).getHost();
@@ -338,31 +310,31 @@ public class OAuthServiceImpl implements OAuthService {
     }
 
     @Override
-    public void deleteAccount(Session session, final int accountId) throws OXException {
+    public void deleteAccount(Session session, int accountId) throws OXException {
         oauthAccountStorage.deleteAccount(session, accountId);
         postOAuthDeleteEvent(accountId, session);
     }
 
     @Override
-    public void updateAccount(Session session, final int accountId, final Map<String, Object> arguments) throws OXException {
+    public void updateAccount(Session session, int accountId, Map<String, Object> arguments) throws OXException {
         oauthAccountStorage.updateAccount(session, accountId, arguments);
     }
 
     @Override
-    public OAuthAccount getAccount(final Session session, final int accountId) throws OXException {
+    public OAuthAccount getAccount(Session session, int accountId) throws OXException {
         return oauthAccountStorage.getAccount(session, accountId);
     }
 
     @Override
-    public OAuthAccount getDefaultAccount(final API api, final Session session) throws OXException {
-        final int contextId = session.getContextId();
-        final int userId = session.getUserId();
-        final List<OAuthServiceMetaData> allServices = registry.getAllServices(userId, contextId);
-        for (final OAuthServiceMetaData metaData : allServices) {
+    public OAuthAccount getDefaultAccount(API api, Session session) throws OXException {
+        int contextId = session.getContextId();
+        int userId = session.getUserId();
+        List<OAuthServiceMetaData> allServices = registry.getAllServices(userId, contextId);
+        for (OAuthServiceMetaData metaData : allServices) {
             if (metaData.getAPI() == api) {
-                final List<OAuthAccount> accounts = getAccounts(session, metaData.getId());
+                List<OAuthAccount> accounts = getAccounts(session, metaData.getId());
                 OAuthAccount likely = null;
-                for (final OAuthAccount acc : accounts) {
+                for (OAuthAccount acc : accounts) {
                     if (likely == null || acc.getId() < likely.getId()) {
                         likely = acc;
                     }
@@ -376,19 +348,18 @@ public class OAuthServiceImpl implements OAuthService {
     }
 
     @Override
-    public OAuthAccount updateAccount(Session session, final int accountId, final String serviceMetaData, final OAuthInteractionType type, final Map<String, Object> arguments, Set<OAuthScope> scopes) throws OXException {
+    public OAuthAccount updateAccount(Session session, int accountId, String serviceMetaData, OAuthInteractionType type, Map<String, Object> arguments, Set<OAuthScope> scopes) throws OXException {
         isNull(arguments, OAuthConstants.ARGUMENT_SESSION);
         DefaultOAuthAccount account = new DefaultOAuthAccount();
 
         OAuthServiceMetaData service = registry.getService(serviceMetaData, session.getUserId(), session.getContextId());
         account.setMetaData(service);
 
-        String displayName = (String) arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME);
+        String displayName = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_DISPLAY_NAME));
         account.setDisplayName(displayName);
         account.setId(accountId);
         obtainToken(type, arguments, account, scopes);
 
-        //Session session = (Session) arguments.get(OAuthConstants.ARGUMENT_SESSION);
         account.setEnabledScopes(scopes);
         // Lazy identity update
         if (!oauthAccountStorage.hasUserIdentity(session, accountId, serviceMetaData)) {
@@ -430,7 +401,7 @@ public class OAuthServiceImpl implements OAuthService {
      * @param userId The user identifier
      * @param contextId The context identifier
      */
-    private void registerTokenForDeferredAccess(final String token, String cbUrl, final DeferringURLService ds, final int userId, final int contextId) {
+    private void registerTokenForDeferredAccess(String token, String cbUrl, DeferringURLService ds, int userId, int contextId) {
         // Is only applicable if call-back URL is deferred; e.g. /ajax/defer?redirect=http:%2F%2Fmy.host.com%2Fpath...
         if (isDeferrerAvailable(ds, userId, contextId)) {
             if (ds.seemsDeferred(cbUrl, userId, contextId)) {
@@ -453,7 +424,7 @@ public class OAuthServiceImpl implements OAuthService {
      * @return <code>true</code> if the {@link DeferringURLService} is not <code>null</code> and available;
      *         <code>false</code> otherwise
      */
-    private boolean isDeferrerAvailable(final DeferringURLService ds, final int userId, final int contextId) {
+    private boolean isDeferrerAvailable(DeferringURLService ds, int userId, int contextId) {
         return null != ds && ds.isDeferrerURLAvailable(userId, contextId);
     }
 
@@ -463,17 +434,17 @@ public class OAuthServiceImpl implements OAuthService {
      * @param accountId The account identifier
      * @param session The session
      */
-    private void postOAuthDeleteEvent(final int accountId, final Session session) {
-        final EventAdmin eventAdmin = Services.getService(EventAdmin.class);
+    private void postOAuthDeleteEvent(int accountId, Session session) {
+        EventAdmin eventAdmin = Services.getService(EventAdmin.class);
         if (null == eventAdmin) {
             return;
         }
-        final Dictionary<String, Object> props = new Hashtable<String, Object>(4);
+        Dictionary<String, Object> props = new Hashtable<String, Object>(4);
         props.put(OAuthEventConstants.PROPERTY_SESSION, session);
         props.put(OAuthEventConstants.PROPERTY_CONTEXT, Integer.valueOf(session.getContextId()));
         props.put(OAuthEventConstants.PROPERTY_USER, Integer.valueOf(session.getUserId()));
         props.put(OAuthEventConstants.PROPERTY_ID, Integer.valueOf(accountId));
-        final Event event = new Event(OAuthEventConstants.TOPIC_DELETE, props);
+        Event event = new Event(OAuthEventConstants.TOPIC_DELETE, props);
         eventAdmin.sendEvent(event);
     }
 
@@ -486,7 +457,7 @@ public class OAuthServiceImpl implements OAuthService {
      * @param scopes The {@link OAuthScope}s
      * @throws OXException if the token cannot be retrieved
      */
-    protected void obtainToken(final OAuthInteractionType type, final Map<String, Object> arguments, final DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
+    protected void obtainToken(OAuthInteractionType type, Map<String, Object> arguments, DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
         switch (type) {
             case OUT_OF_BAND:
                 obtainTokenByOutOfBand(arguments, account, scopes);
@@ -507,7 +478,7 @@ public class OAuthServiceImpl implements OAuthService {
      * @param scopes The {@link OAuthScope}s
      * @throws OXException if the token cannot be retrieved
      */
-    private void obtainTokenByCallback(final Map<String, Object> arguments, final DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
+    private void obtainTokenByCallback(Map<String, Object> arguments, DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
         obtainTokenByOutOfBand(arguments, account, scopes);
     }
 
@@ -519,25 +490,32 @@ public class OAuthServiceImpl implements OAuthService {
      * @param scopes The {@link OAuthScope}s
      * @throws OXException if the token cannot be retrieved
      */
-    private void obtainTokenByOutOfBand(final Map<String, Object> arguments, final DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
+    private void obtainTokenByOutOfBand(Map<String, Object> arguments, DefaultOAuthAccount account, Set<OAuthScope> scopes) throws OXException {
         try {
-            final OAuthServiceMetaData metaData = account.getMetaData();
-            final OAuthToken oAuthToken = metaData.getOAuthToken(arguments, scopes);
+            OAuthServiceMetaData metaData = account.getMetaData();
+            OAuthToken oAuthToken = metaData.getOAuthToken(arguments, scopes);
             if (null == oAuthToken) {
                 isNull(arguments, OAuthConstants.ARGUMENT_PIN, OAuthConstants.ARGUMENT_REQUEST_TOKEN);
 
-                String pin = (String) arguments.get(OAuthConstants.ARGUMENT_PIN);
+                String pin = String.class.cast(arguments.get(OAuthConstants.ARGUMENT_PIN));
                 OAuthToken requestToken = (OAuthToken) arguments.get(OAuthConstants.ARGUMENT_REQUEST_TOKEN);
                 Session session = (Session) arguments.get(OAuthConstants.ARGUMENT_SESSION);
                 // With the request token and the verifier (which is a number) we need now to get the access token
-                final Verifier verifier = new Verifier(pin);
-                final org.scribe.oauth.OAuthService service = getScribeService(account.getMetaData(), null, session, scopes);
-                final Token accessToken = service.getAccessToken(new Token(requestToken.getToken(), requestToken.getSecret()), verifier);
+                Verifier verifier = new Verifier(pin);
+                org.scribe.oauth.OAuthService service = getScribeService(account.getMetaData(), null, session, scopes);
+                Token accessToken = service.getAccessToken(new Token(requestToken.getToken(), requestToken.getSecret()), verifier);
                 account.setToken(accessToken.getToken());
                 account.setSecret(accessToken.getSecret());
+                
+                // Only OAuth 2.0 tokens have an expiry timestamp 
+                // Temporary fix until we switch to OAuth 2.0 in all bundles
+                if (service instanceof OAuth20ServiceImpl) {
+                    account.setExpiration(accessToken.getExpiry() == null ? 0L : accessToken.getExpiry().getTime());
+                }
             } else {
                 account.setToken(oAuthToken.getToken());
                 account.setSecret(oAuthToken.getSecret());
+                account.setExpiration(oAuthToken.getExpiration());
             }
         } catch (org.scribe.exceptions.OAuthException e) {
             throw handleScribeOAuthException(e);
@@ -556,8 +534,8 @@ public class OAuthServiceImpl implements OAuthService {
      * @return The {@link org.scribe.oauth.OAuthService}
      * @throws OXException if the desired service is not supported
      */
-    private org.scribe.oauth.OAuthService getScribeService(final OAuthServiceMetaData metaData, final String callbackUrl, Session session, Set<OAuthScope> scopes) throws OXException {
-        final Class<? extends Api> apiClass;
+    private org.scribe.oauth.OAuthService getScribeService(OAuthServiceMetaData metaData, String callbackUrl, Session session, Set<OAuthScope> scopes) throws OXException {
+        Class<? extends Api> apiClass;
         if (metaData instanceof com.openexchange.oauth.impl.ScribeAware) {
             apiClass = ((com.openexchange.oauth.impl.ScribeAware) metaData).getScribeService();
         } else {
@@ -568,7 +546,7 @@ public class OAuthServiceImpl implements OAuthService {
             }
             apiClass = knownApi.getApiClass();
         }
-        final ServiceBuilder serviceBuilder = new ServiceBuilder().provider(apiClass);
+        ServiceBuilder serviceBuilder = new ServiceBuilder().provider(apiClass);
         serviceBuilder.apiKey(metaData.getAPIKey(session)).apiSecret(metaData.getAPISecret(session));
         if (null != callbackUrl) {
             serviceBuilder.callback(callbackUrl);
@@ -590,25 +568,25 @@ public class OAuthServiceImpl implements OAuthService {
      * @return An {@link OXException}
      */
     private OXException handleScribeOAuthException(org.scribe.exceptions.OAuthException e) {
-        final String message = e.getMessage();
+        String message = e.getMessage();
         if (null != message) {
-            final String lcMsg = com.openexchange.java.Strings.toLowerCase(message);
+            String lcMsg = com.openexchange.java.Strings.toLowerCase(message);
             String str = "can't extract token and secret from this:";
             int pos = lcMsg.indexOf(str);
             if (pos > 0) {
-                final String msg = toText(message.substring(pos + str.length()));
+                String msg = toText(message.substring(pos + str.length()));
                 return OAuthExceptionCodes.DENIED_BY_PROVIDER.create(e, msg);
             }
             str = "can't extract a token from an empty string";
             pos = lcMsg.indexOf(str);
             if (pos > 0) {
-                final String msg = toText(message.substring(pos));
+                String msg = toText(message.substring(pos));
                 return OAuthExceptionCodes.DENIED_BY_PROVIDER.create(e, msg);
             }
             str = "can't extract a token from this:";
             pos = lcMsg.indexOf(str);
             if (pos > 0) {
-                final String msg = toText(message.substring(pos + str.length()));
+                String msg = toText(message.substring(pos + str.length()));
                 return OAuthExceptionCodes.DENIED_BY_PROVIDER.create(e, msg);
             }
         }
@@ -624,8 +602,8 @@ public class OAuthServiceImpl implements OAuthService {
      * @param msg the message to convert
      * @return The converted message
      */
-    private String toText(final String msg) {
-        final HtmlService htmlService = Services.getService(HtmlService.class);
+    private String toText(String msg) {
+        HtmlService htmlService = Services.getService(HtmlService.class);
         if (null == htmlService) {
             return msg;
         }
